pub struct Node<T>where
T: Chunk,{
pub path: PathBuf,
pub chunk: T,
pub vectors: Option<HashMap<EmbeddedField, Vec<f32>>>,
pub sparse_vectors: Option<HashMap<EmbeddedField, SparseEmbedding>>,
pub metadata: Metadata,
pub embed_mode: EmbedMode,
pub original_size: usize,
pub offset: usize,
}Expand description
Represents a unit of data in the indexing process.
Node encapsulates all necessary information for a single unit of data being processed
in the indexing pipeline. It includes fields for an identifier, file path, data chunk, optional
vector representation, and metadata.
Fields
path: PathBufFile path associated with the node.
chunk: TData chunk contained in the node.
vectors: Option<HashMap<EmbeddedField, Vec<f32>>>Optional vector representation of embedded data.
sparse_vectors: Option<HashMap<EmbeddedField, SparseEmbedding>>Optional sparse vector representation of embedded data.
metadata: MetadataMetadata associated with the node.
embed_mode: EmbedModeMode of embedding data Chunk and Metadata
original_size: usizeSize of the input this node was originally derived from in bytes
offset: usizeOffset of the chunk relative to the start of the input this node was originally derived from in bytes
Implementations
Sourceimpl<T> Node<T>where
T: Chunk,
impl<T> Node<T>where
T: Chunk,
Sourcepub fn build_from_other(node: &Node<T>) -> NodeBuilder<T>
pub fn build_from_other(node: &Node<T>) -> NodeBuilder<T>
Builds a new instance of Node, returning a NodeBuilder. Copies
over the fields from the provided Node.
Sourcepub fn builder<VALUE>() -> NodeBuilder<VALUE>
pub fn builder<VALUE>() -> NodeBuilder<VALUE>
Creates a new instance of NodeBuilder.
Sourcepub fn new(chunk: impl Into<String>) -> Node<String>
pub fn new(chunk: impl Into<String>) -> Node<String>
Creates a new instance of Node with the specified data chunk.
The other fields are set to their default values.
pub fn with_metadata(&mut self, metadata: impl Into<Metadata>) -> &mut Node<T>
pub fn with_vectors( &mut self, vectors: impl Into<HashMap<EmbeddedField, Vec<f32>>>, ) -> &mut Node<T>
pub fn with_sparse_vectors( &mut self, sparse_vectors: impl Into<HashMap<EmbeddedField, SparseEmbedding>>, ) -> &mut Node<T>
Sourceimpl Node<String>
impl Node<String>
Sourcepub fn as_embeddables(&self) -> Vec<(EmbeddedField, String)>
pub fn as_embeddables(&self) -> Vec<(EmbeddedField, String)>
Creates embeddable data depending on chosen EmbedMode.
Returns
Embeddable data mapped to their EmbeddedField.